"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createThemeGlobalStyles = void 0;
const styled_reset_1 = __importDefault(require("styled-reset"));
const hTags_1 = require("./hTags");
const milligram_1 = require("./milligram");
const createThemeGlobalStyles = (theme, options) => {
    var _a, _b, _c;
    return `
  ${((_a = options === null || options === void 0 ? void 0 : options.include) === null || _a === void 0 ? void 0 : _a.cssReset) !== false ? styled_reset_1.default : ''}
  ${((_b = options === null || options === void 0 ? void 0 : options.include) === null || _b === void 0 ? void 0 : _b.milligram) ? milligram_1.milligram : ''}

  html {
    background-color: ${theme.colors.white.val};
  }
  body {
    color: ${theme.colors.text.val};
    font-size: ${theme.sizes.font.base.val};
    font-family: ${theme.fonts.textFamily};
  }

  p,span,button,a,ul,li,textarea,input,blockquote,pre,div,aside,nav,header,footer,cite,section,ol {
    font-size: inherit;
    font-weight: inherit;
    font-family: inherit;
  }
  
  div,ul,li,a,p,h1,h2,h3,h4,h5,h6,pre,blockquote,cite,header,footer,main,body,section,aside {
    position: relative;
  }

  p,div,h1,h2,h3,h4,h5,h6,section,aside,header,footer,blockquote,ul,ol,nav,legend,label,li {
    display: block;
    box-sizing: border-box;
  }

  p {
    margin: 0.5em 0;
  }
  
  a {
    color: ${theme.colors.secondary.val};
    text-decoration: none;
    &:hover {
      color: ${theme.colors.secondary.bright(0).val};
    }
  }

  em, i {
    font-style: italic;
  }

  strong {
    font-weight: bolder;
  }

  h1, h2, h3, h4, h5, h6 {
    font-family: ${theme.fonts.titleFamily};
  }

  ${((_c = options === null || options === void 0 ? void 0 : options.include) === null || _c === void 0 ? void 0 : _c.fluidHeadings) ? hTags_1.fluidHeadingSizes(theme) : ''}

  .overlay {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 10;
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: ${theme.colors.black.tint(8)};
  }

  button, a, input, textarea {
    outline: none;
    box-sizing: border-box;
    box-shadow: none;
    background: none;
    border-color: inherit;

    transition: all ${theme.times.tranS};

    &:hover, &:focus {
      outline: none;
    }
    &:hover {
      cursor: pointer;
    }
    
    &:disabled {
      color: ${theme.colors.disabled.val};
      border-color: ${theme.colors.disabled.val};
      fill: ${theme.colors.disabled.val};
      &:hover, &:focus {
        color: ${theme.colors.disabled.val};
        border-color: ${theme.colors.disabled.val};
        fill: ${theme.colors.disabled.val};
      }
      &:hover {
        cursor: default;
      }
    }
  }

  ul {
    list-style-type: none;
  }

  .rt, .rich-text {
    ul, ol {
      margin: .5em 1em .5em 2em;
    }
    ul {
      list-style-type: disc;
    }
    ol {
      list-style-type: decimal;
    }
  }

  /* Column layout classes */
  .cols {
    display: flex;
    width: 100%;
    align-items: stretch;
    &.cols-tablet {
      display: block;
      width: auto;
      ${theme.media.tablet} {
        display: flex;
        width: 100%;
      }
    }
    &.cols-sdesk {
      display: block;
      width: auto;
      ${theme.media.sdesk} {
        display: flex;
        width: 100%;
      }
    }
    & > *{
      flex-grow: 1;
    }
  }

  /* Flex utilities */
  .flex {
		display: flex;
	}
	.flex-tablet {
		${theme.media.sdesk} {
			display: flex;
		}
	}
	.flex-desk {
		${theme.media.sdesk} {
			display: flex;
		}
	}
`;
};
exports.createThemeGlobalStyles = createThemeGlobalStyles;
//# sourceMappingURL=globalStyles.js.map