"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SwfColor = void 0;
const tinycolor2_1 = __importDefault(require("tinycolor2"));
const calcAmount = ({ val, fallback }) => {
    let amount = fallback;
    let preset = null;
    if (typeof val === 'number') {
        if (val < 7) {
            preset = val.toString();
        }
        else
            amount = val;
    }
    else if (typeof val === 'string') {
        preset = val;
    }
    if (preset) {
        switch (preset) {
            case '0':
                amount = fallback * 0.4;
                break;
            case '1':
                amount = fallback * 0.6;
                break;
            case '2':
                amount = fallback * 0.8;
                break;
            case '3':
                amount = fallback;
                break;
            case '4':
                amount = fallback * 1.2;
                break;
            case '5':
                amount = fallback * 1.4;
                break;
            case '6':
                amount = fallback * 1.6;
                break;
            default:
        }
    }
    return amount;
};
class SwfColor {
    constructor(colorName, config) {
        this.dark = val => {
            const amount = calcAmount({ val, fallback: this.conf.dark });
            const Color = tinycolor2_1.default(this.val).darken(amount);
            return new SwfColor(Color.toString(), this.config);
        };
        this.light = val => {
            const amount = calcAmount({ val, fallback: this.conf.light });
            const Color = tinycolor2_1.default(this.val).lighten(amount);
            return new SwfColor(Color.toString(), this.config);
        };
        this.bright = val => {
            const amount = calcAmount({ val, fallback: this.conf.bright });
            const Color = tinycolor2_1.default(this.val).brighten(amount);
            return new SwfColor(Color.toString(), this.config);
        };
        this.sat = val => {
            const amount = calcAmount({ val, fallback: this.conf.sat });
            const Color = tinycolor2_1.default(this.val).saturate(amount);
            return new SwfColor(Color.toString(), this.config);
        };
        this.desat = val => {
            const amount = calcAmount({ val, fallback: this.conf.desat });
            const Color = tinycolor2_1.default(this.val).desaturate(amount);
            return new SwfColor(Color.toString(), this.config);
        };
        this.tint = (amount) => {
            let tintAmount = typeof amount === 'number' ? amount : this.conf.tint;
            tintAmount = tintAmount * 0.01;
            const Color = tinycolor2_1.default(this.val).setAlpha(tintAmount);
            return new SwfColor(Color.toString(), this.config);
        };
        this.invert = () => {
            const Color = tinycolor2_1.default(this.val);
            let colorVal;
            if (Color.isDark()) {
                colorVal = this.conf.white;
            }
            else if (Color.isLight()) {
                colorVal = this.conf.black;
            }
            else
                colorVal = Color.spin(180).toString();
            return new SwfColor(colorVal, this.config);
        };
        const { darken, lighten, brighten, tint, desaturate, saturate } = config.fallbacks;
        this.val = config.colors[colorName] ? config.colors[colorName] : colorName;
        this.name = colorName;
        this.conf = {
            dark: colorName === 'grey' ? darken * 1.5 : darken,
            light: lighten,
            bright: brighten,
            tint,
            black: config.colors.black,
            white: config.colors.white,
            desat: desaturate,
            sat: saturate,
        };
        this.config = config;
    }
}
exports.SwfColor = SwfColor;
//# sourceMappingURL=SwfColor.js.map