"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFonts = exports.fluidFontSize = exports.generateHsizes = void 0;
const round_1 = __importDefault(require("lodash/round"));
const generateHsizes = (opts = {}) => {
    const { unit = 'em', max = 4, min = 1.1 } = opts;
    return Array(6)
        .fill('')
        .reduce((acc, _, i) => {
        const num = round_1.default(max - ((max - min) / 5) * i, 2);
        const key = `h${i + 1}`;
        const res = acc;
        res[key] = {
            num,
            val: `${num}${unit}`,
        };
        return res;
    }, {});
};
exports.generateHsizes = generateHsizes;
const fluidFontSize = ({ maxSize = 25, minSize = 15, minViewport = 320, maxViewport = 1480, } = {}) => `
    font-size: calc(
      ${minSize}px + ${maxSize - minSize} *
        ((100vw - ${minViewport}px) / ${maxViewport - minViewport})
    );

    @media screen and (max-width: ${minViewport}px) {
      font-size: ${minSize}px;
    }
    @media screen and (min-width: ${maxViewport}px) {
      font-size: ${maxSize}px;
    }
  `;
exports.fluidFontSize = fluidFontSize;
const createFonts = (options = {}) => {
    const config = Object.assign({ textFamily: 'PT-Sans, sans-serif', titleFamily: 'PT-Sans, sans-serif' }, options);
    return Object.assign(Object.assign({}, config), { fluidFontSize: exports.fluidFontSize });
};
exports.createFonts = createFonts;
//# sourceMappingURL=fonts.js.map